Defines a hierarchy of error classes for MLSampling to ensure consistent error reporting and handling across all modules.
Examples
if (FALSE) { # \dontrun{
stop(MLSamplingError("General error"))
stop(BDLError("Model failed to converge"))
} # }
Defines a hierarchy of error classes for MLSampling to ensure consistent error reporting and handling across all modules.
if (FALSE) { # \dontrun{
stop(MLSamplingError("General error"))
stop(BDLError("Model failed to converge"))
} # }